@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2010 Jordi Mas i Hernàndez <jmas@softcatala.org>
+ * Copyright (C) 2007-2011 Jordi Mas i Hernàndez <jmas@softcatala.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,14 +18,15 @@
  */
 
 using System;
-using Cairo;
 using Gtk;
 using Mono.Unix;
 using System.Diagnostics;
 using Gdk;
+using System.Reflection;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Platform;
+using gbrainy.Core.Services;
 using gbrainy.Clients.Classical.Dialogs;
 using gbrainy.Clients.Classical.Widgets;
 
@@ -46,16 +47,16 @@ namespace gbrainy.Clients.Classical
 #endif
 	{
 		[GtkBeans.Builder.Object("gbrainy")] Gtk.Window app_window;
-		[GtkBeans.Builder.Object] Gtk.CheckMenuItem toolbar_menuitem;
+		[GtkBeans.Builder.Object] Gtk.CheckMenuItem showtoolbar_menuitem;
 		[GtkBeans.Builder.Object] Box drawing_vbox;
-		[GtkBeans.Builder.Object] Gtk.VBox question_vbox;
-		[GtkBeans.Builder.Object] Gtk.VBox solution_vbox;
+		[GtkBeans.Builder.Object] Gtk.HBox main_hbox;
+		[GtkBeans.Builder.Object] Gtk.VBox framework_vbox;
 		[GtkBeans.Builder.Object] Gtk.Entry answer_entry;
 		[GtkBeans.Builder.Object] Gtk.Button answer_button;
+		[GtkBeans.Builder.Object] Gtk.Label answer_label;
 		[GtkBeans.Builder.Object] Gtk.Button tip_button;
 		[GtkBeans.Builder.Object] Gtk.Button next_button;
 		[GtkBeans.Builder.Object] Gtk.Statusbar statusbar;
-		[GtkBeans.Builder.Object] Gtk.Toolbar toolbar;
 		[GtkBeans.Builder.Object] Gtk.MenuBar menubar;
 		[GtkBeans.Builder.Object] Gtk.MenuItem pause_menuitem;
 		[GtkBeans.Builder.Object] Gtk.MenuItem finish_menuitem;
@@ -66,25 +67,30 @@ namespace gbrainy.Clients.Classical
 		[GtkBeans.Builder.Object] Gtk.MenuItem memory_menuitem;
 		[GtkBeans.Builder.Object] Gtk.MenuItem verbal_menuitem;
 		[GtkBeans.Builder.Object] Gtk.MenuItem extensions_menuitem;
+		[GtkBeans.Builder.Object] Gtk.RadioMenuItem vertical_radiomenuitem;
+		[GtkBeans.Builder.Object] Gtk.RadioMenuItem horizontal_radiomenuitem;
+		[GtkBeans.Builder.Object] Gtk.MenuItem toolbar_orientation_menuitem;
 
-		DrawingArea drawing_area;
+		Widgets.Toolbar toolbar;
+
+		GameDrawingArea drawing_area;
 		GameSession session;
-		ToolButton all_tbbutton, logic_tbbutton, calculation_tbbutton, memory_tbbutton, verbal_tbbutton, pause_tbbutton, finish_tbbutton;
 		bool low_res;
 		bool full_screen;
-		SimpleLabel question_label;
-		SimpleLabel solution_label;
-		bool margins = false;
-		double offset_x, offset_y;
-		int drawing_square;
 		GameSession.Types initial_session;
 
+		public readonly int MIN_TRANSLATION = 80;
+
 		public GtkClient ()
 #if GNOME
 		: base ("gbrainy", Defines.VERSION, Modules.UI, new string [0])
 #endif
 		{
-			Catalog.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
+			if (Preferences.Get <bool> (Preferences.EnglishKey) == false)
+			{
+				Catalog.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
+			}
+
 			Unix.FixLocaleInfo ();
 		}
 
@@ -103,11 +109,11 @@ namespace gbrainy.Clients.Classical
 			GameManagerPreload (session.GameManager);
 			Console.WriteLine (session.GameManager.GetGamesSummary ());
 
-			session.GameManager.ColorBlind = Preferences.GetBoolValue (Preferences.ColorBlindKey);
+			session.GameManager.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
 			session.DrawRequest += SessionDrawRequest;
 			session.UpdateUIElement += SessionUpdateUIElement;
 			session.SynchronizingObject = new GtkSynchronize ();
-			session.Difficulty = (GameDifficulty) Preferences.GetIntValue (Preferences.DifficultyKey);
+			session.Difficulty = (GameDifficulty) Preferences.Get <int> (Preferences.DifficultyKey);
 
 			BuildUI ();
 		}
@@ -127,10 +133,21 @@ namespace gbrainy.Clients.Classical
 			GtkBeans.Builder builder = new GtkBeans.Builder ("gbrainy.ui");
 			builder.Autoconnect (this);
 
-			BuildToolBar ();
+			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true && low_res == false;
 
-			drawing_area = new DrawingArea ();
-			drawing_area.ExposeEvent += OnDrawingAreaExposeEvent;
+			// Toolbar creation
+			toolbar = new Widgets.Toolbar (main_hbox, framework_vbox);
+			toolbar.Attach ((Gtk.Orientation) Preferences.Get <int> (Preferences.ToolbarOrientationKey));
+			toolbar.AllButton.Clicked += OnAllGames;
+			toolbar.LogicButton.Clicked += OnLogicOnly;
+			toolbar.CalculationButton.Clicked += OnMathOnly;
+			toolbar.MemoryButton.Clicked += OnMemoryOnly;
+			toolbar.VerbalButton.Clicked += OnVerbalOnly;
+			toolbar.PauseButton.Clicked += OnPauseGame;
+			toolbar.FinishButton.Clicked += OnEndGame;
+
+			drawing_area = new GameDrawingArea ();
+			drawing_area.Drawable = session;
 			GameSensitiveUI ();
 
 			// For low resolutions, hide the toolbar and made the drawing area smaller
@@ -141,14 +158,6 @@ namespace gbrainy.Clients.Classical
 				}
 			}
 
-			question_label = new SimpleLabel ();
-			question_label.HeightMargin = 2;
-			question_vbox.Add (question_label);
-
-			solution_label = new SimpleLabel ();
-			solution_label.HeightMargin = 2;
-			solution_vbox.Add (solution_label);
-
 			EventBox eb = new EventBox (); // Provides a window for drawing area windowless widget
 
 			eb.Events = Gdk.EventMask.PointerMotionMask;
@@ -159,18 +168,35 @@ namespace gbrainy.Clients.Classical
 			eb.MotionNotifyEvent += OnMouseMotionEvent;
 			eb.ButtonPressEvent += OnHandleButtonPress;
 
-			show_toolbar = Preferences.GetBoolValue (Preferences.ToolbarKey) == true && low_res == false;
+			show_toolbar = Preferences.Get <bool> (Preferences.ToolbarShowKey) == true && low_res == false;
 
 			// We only disable the Arrow if we are going to show the toolbar.
-			// It has an impact on the total window width size even if you we do not show it
+			// It has an impact on the total window width size even if we do not show it
 			if (show_toolbar)
 				toolbar.ShowArrow = false;
 
 			app_window.IconName = "gbrainy";
+
 			app_window.ShowAll ();
 
+			toolbar_orientation_menuitem.Sensitive = toolbar.Visible;
+
+			// Check default radio button
+			switch (toolbar.Orientation) {
+			case Gtk.Orientation.Vertical:
+				vertical_radiomenuitem.Active = true;
+				break;
+			case Gtk.Orientation.Horizontal:
+				horizontal_radiomenuitem.Active = true;
+				break;
+			default:
+				throw new InvalidOperationException ();
+			}
+
+			// The toolbar by default is enabled. By setting this menu entry to false
+			// triggers the OnActivateToolbar event that hides the toolbar
 			if (show_toolbar == false)
-				toolbar_menuitem.Active = false;
+				showtoolbar_menuitem.Active = false;
 
 		#if MONO_ADDINS
 			extensions_menuitem.Activated += delegate (object sender, EventArgs ar) { Mono.Addins.Gui.AddinManagerWindow.Run (app_window);};
@@ -208,38 +234,6 @@ namespace gbrainy.Clients.Classical
 			drawing_area.QueueDraw ();
 		}
 
-		void OnDrawingAreaExposeEvent (object o, ExposeEventArgs ar)
-		{
-			Gdk.EventExpose args = ar.Event;
-
-			int w, h;
-			args.Window.GetSize (out w, out h);
-
-			Cairo.Context cc = Gdk.CairoHelper.Create (args.Window);
-			CairoContextEx cr = new CairoContextEx (cc.Handle, drawing_area);
-
-			// We want a square drawing area for the puzzles then the figures are shown as designed.
-			// For example, squares are squares. This also makes sure that proportions are kept when resizing
-			drawing_square = Math.Min (w, h);
-
-			if (drawing_square < w)
-				offset_x = (w - drawing_square) / 2;
-
-			if (drawing_square < h)
-				offset_y = (h - drawing_square) / 2;
-
-			if (margins)
-				SetMargin ((int) offset_x);
-			else
-				SetMargin (2);
-
-			cr.Translate (offset_x, offset_y);
-			session.Draw (cr, drawing_square, drawing_square, drawing_area.Direction == Gtk.TextDirection.Rtl);
-
-			((IDisposable)cc).Dispose();
-			((IDisposable)cr).Dispose();
-		}
-
 		void OnMouseMotionEvent (object o, MotionNotifyEventArgs ev_args)
 		{
 			SendMouseEvent (ev_args.Event.X, ev_args.Event.Y, MouseEventType.Move);
@@ -256,9 +250,10 @@ namespace gbrainy.Clients.Classical
 		void SendMouseEvent (double ev_x, double ev_y, MouseEventType type)
 		{
 			double x, y;
+			int drawing_square = drawing_area.DrawingSquare;
 
-			x = ev_x - offset_x;
-			y = ev_y - offset_y;
+			x = ev_x - drawing_area.OffsetX;
+			y = ev_y - drawing_area.OffsetY;
 
 			if (x < 0 || y < 0 || x > drawing_square || y > drawing_square)
 				return;
@@ -277,9 +272,9 @@ namespace gbrainy.Clients.Classical
 		// These are UI elements dependent of the game status
 		public void ActiveInputControls (bool active)
 		{
-			bool answer, entry, next, tip, can_pause;
+			bool answer, next, tip, can_pause;
 
-			can_pause = answer = entry = next = tip = active;
+			can_pause = answer = next = tip = active;
 
 			if (active == true && session.CurrentGame != null && session.CurrentGame.ButtonsActive == true && String.IsNullOrEmpty (session.CurrentGame.Tip ) == false)
 				tip = true;
@@ -290,7 +285,6 @@ namespace gbrainy.Clients.Classical
 			case GameSession.SessionStatus.NotPlaying:
 			case GameSession.SessionStatus.Finished:
 				answer = false;
-				entry = false;
 				next = false;
 				tip = false;
 				can_pause = false;
@@ -305,25 +299,25 @@ namespace gbrainy.Clients.Classical
 				break;
 			case GameSession.SessionStatus.Answered:
 				answer = false;
-				entry = false;
 				tip = false;
 				can_pause = false;
 				break;
 			}
 
 			answer_button.Sensitive = answer;
-			answer_entry.Sensitive = entry;
+			answer_entry.Sensitive = answer;
+			answer_label.Sensitive = answer;
 			next_button.Sensitive = next;
 			tip_button.Sensitive = tip;
-			pause_menuitem.Sensitive = pause_tbbutton.Sensitive = can_pause;
+			pause_menuitem.Sensitive = toolbar.PauseButton.Sensitive = can_pause;
 
-			if (entry == true)
+			if (answer == true)
 				answer_entry.GrabFocus ();
 		}
 
 		public void UpdateQuestion (string question)
 		{
-			question_label.Text = question;
+			drawing_area.Question = question;
 		}
 
 		public void QueueDraw ()
@@ -331,73 +325,11 @@ namespace gbrainy.Clients.Classical
 			drawing_area.QueueDraw ();
 		}
 
-		public void SetMargin (int margin)
+		void UpdateSolution (string solution, GameDrawingArea.SolutionType solution_type)
 		{
-			question_label.WidthMargin = margin;
-			solution_label.WidthMargin = margin;
-		}
-
-		void UpdateSolution (string solution)
-		{
-			solution_label.Text = solution;
-		}
-
-		void BuildToolBar ()
-		{
-			IconFactory icon_factory = new IconFactory ();
-		        AddIcon (icon_factory, "logic-games", "logic-games-32.png");
-			AddIcon (icon_factory, "math-games", "math-games-32.png");
-			AddIcon (icon_factory, "memory-games", "memory-games-32.png");
-			AddIcon (icon_factory, "verbal-games", "verbal-games-32.png");
-			AddIcon (icon_factory, "pause", "pause-32.png");
-			AddIcon (icon_factory, "resume", "resume-32.png");
-			AddIcon (icon_factory, "endgame", "endgame-32.png");
-			AddIcon (icon_factory, "allgames", "allgames-32.png");
-			icon_factory.AddDefault ();
-
-			toolbar.IconSize = Gtk.IconSize.Dnd;
-
-			all_tbbutton = new ToolButton ("allgames");
-			all_tbbutton.TooltipText = Catalog.GetString ("Play all the games");
-			all_tbbutton.Label = Catalog.GetString ("All");
-			all_tbbutton.Clicked += OnAllGames;
-			toolbar.Insert (all_tbbutton, -1);
-
-			logic_tbbutton = new ToolButton ("logic-games");
-			logic_tbbutton.TooltipText = Catalog.GetString ("Play games that challenge your reasoning and thinking");
-			logic_tbbutton.Label = Catalog.GetString ("Logic");
-			logic_tbbutton.Clicked += OnLogicOnly;
-			toolbar.Insert (logic_tbbutton, -1);
-
-			calculation_tbbutton = new ToolButton ("math-games");
-			calculation_tbbutton.Label = Catalog.GetString ("Calculation");
-			calculation_tbbutton.TooltipText = Catalog.GetString ("Play games that challenge your mental calculation skills");
-			calculation_tbbutton.Clicked += OnMathOnly;
-			toolbar.Insert (calculation_tbbutton, -1);
-
-			memory_tbbutton = new ToolButton ("memory-games");
-			memory_tbbutton.Label = Catalog.GetString ("Memory");
-			memory_tbbutton.TooltipText = Catalog.GetString ("Play games that challenge your short term memory");
-			memory_tbbutton.Clicked += OnMemoryOnly;
-			toolbar.Insert (memory_tbbutton, -1);
-
-			verbal_tbbutton = new ToolButton ("verbal-games");
-			verbal_tbbutton.Label = Catalog.GetString ("Verbal");
-			verbal_tbbutton.TooltipText = Catalog.GetString ("Play games that challenge your verbal aptitude");
-			verbal_tbbutton.Clicked += OnVerbalOnly;
-			toolbar.Insert (verbal_tbbutton, -1);
-
-			pause_tbbutton = new ToolButton ("pause");
-			pause_tbbutton.Label = Catalog.GetString ("Pause");
-			pause_tbbutton.TooltipText = Catalog.GetString ("Pause or resume the game");
-			pause_tbbutton.Clicked += OnPauseGame;
-			toolbar.Insert (pause_tbbutton, -1);
-
-			finish_tbbutton = new ToolButton ("endgame");
-			finish_tbbutton.TooltipText = Catalog.GetString ("End the game and show score");
-			finish_tbbutton.Label = Catalog.GetString ("Finish");
-			finish_tbbutton.Clicked += OnEndGame;
-			toolbar.Insert (finish_tbbutton, -1);
+			drawing_area.Solution = solution;
+			drawing_area.SolutionIcon = solution_type;
+			QueueDraw ();
 		}
 
 		// These are UI elements independent of the game status, set only when the game starts / ends
@@ -408,34 +340,34 @@ namespace gbrainy.Clients.Classical
 			GameTypes available;
 
 			playing = (session.Status == GameSession.SessionStatus.Playing);
-			finish_tbbutton.Sensitive = playing;
+			toolbar.FinishButton.Sensitive = playing;
 
 			available = session.AvailableGames;
 
 			if (playing == false && ((available & GameTypes.LogicPuzzle) == GameTypes.LogicPuzzle))
-				logic_menuitem.Sensitive = logic_tbbutton.Sensitive = true;
+				logic_menuitem.Sensitive = toolbar.LogicButton.Sensitive = true;
 			else
-				logic_menuitem.Sensitive = logic_tbbutton.Sensitive = false;
+				logic_menuitem.Sensitive = toolbar.LogicButton.Sensitive = false;
 
 			if (playing == false && ((available & GameTypes.Calculation) == GameTypes.Calculation))
-				memory_menuitem.Sensitive = memory_tbbutton.Sensitive = true;
+				memory_menuitem.Sensitive = toolbar.MemoryButton.Sensitive = true;
 			else
-				memory_menuitem.Sensitive = memory_tbbutton.Sensitive = false;
+				memory_menuitem.Sensitive = toolbar.MemoryButton.Sensitive = false;
 
 			if (playing == false && ((available & GameTypes.Calculation) == GameTypes.Calculation))
-				calculation_menuitem.Sensitive = calculation_tbbutton.Sensitive = true;
+				calculation_menuitem.Sensitive = toolbar.CalculationButton.Sensitive = true;
 			else
-				calculation_menuitem.Sensitive = calculation_tbbutton.Sensitive = false;
+				calculation_menuitem.Sensitive = toolbar.CalculationButton.Sensitive = false;
 
 			if (playing == false && ((available & GameTypes.VerbalAnalogy) == GameTypes.VerbalAnalogy))
-				verbal_menuitem.Sensitive = verbal_tbbutton.Sensitive = true;
+				verbal_menuitem.Sensitive = toolbar.VerbalButton.Sensitive = true;
 			else
-				verbal_menuitem.Sensitive = verbal_tbbutton.Sensitive = false;
+				verbal_menuitem.Sensitive = toolbar.VerbalButton.Sensitive = false;
 
 			if (playing == false && (available != GameTypes.None))
-				allgames_menuitem.Sensitive = all_tbbutton.Sensitive = true;
+				allgames_menuitem.Sensitive = toolbar.AllButton.Sensitive = true;
 			else
-				allgames_menuitem.Sensitive = all_tbbutton.Sensitive = false;
+				allgames_menuitem.Sensitive = toolbar.AllButton.Sensitive = false;
 
 			finish_menuitem.Sensitive = playing;
 			newgame_menuitem.Sensitive = !playing;
@@ -443,8 +375,13 @@ namespace gbrainy.Clients.Classical
 
 		private void GetNextGame ()
 		{
-			UpdateSolution (String.Empty);
+			UpdateSolution (String.Empty, GameDrawingArea.SolutionType.None);
 			UpdateQuestion (String.Empty);
+
+			if (session.CurrentGame != null) {
+				session.CurrentGame.AnswerEvent -= OnAnswerFromGame;
+			}
+
 			session.NextGame ();
 			session.CurrentGame.AnswerEvent += OnAnswerFromGame;
 
@@ -453,14 +390,14 @@ namespace gbrainy.Clients.Classical
 			UpdateQuestion (session.CurrentGame.Question);
 			answer_entry.Text = string.Empty;
 			UpdateStatusBar ();
-			session.CurrentGame.DrawAnswer = false;
+			session.CurrentGame.Answer.Draw = false;
 			drawing_area.QueueDraw ();
 		}
 
 		// The user has clicked with the mouse in an answer and generated this event
-		void OnAnswerFromGame (object obj, Game.AnswerEventArgs args)
+		void OnAnswerFromGame (object obj, GameAnswerEventArgs args)
 		{
-			answer_entry.Text = args.Answer;
+			answer_entry.Text = args.AnswerText;
 			OnAnswerButtonClicked (this, EventArgs.Empty);
 			session.CurrentGame.AnswerEvent -= OnAnswerFromGame; // User can only answer once
 		}
@@ -480,21 +417,25 @@ namespace gbrainy.Clients.Classical
 		void OnAnswerButtonClicked (object sender, EventArgs args)
 		{
 			string answer;
+			bool correct;
 
 			if (session.CurrentGame == null)
 				return;
 
-			if (session.ScoreGame (answer_entry.Text) == true)
-				answer = "<span color='#00A000'>" + Catalog.GetString ("Congratulations.") + "</span>";
+			correct = session.ScoreGame (answer_entry.Text);
+			if (correct)
+				answer = Catalog.GetString ("Congratulations.");
 			else
 				answer = Catalog.GetString ("Incorrect answer.");
 
 			session.EnableTimer = false;
 			answer_entry.Text = String.Empty;
 			UpdateStatusBar ();
-			UpdateSolution (answer + " " + session.CurrentGame.Answer);
+			UpdateSolution (answer + " " + session.CurrentGame.AnswerText,
+				correct == true ? GameDrawingArea.SolutionType.CorrectAnswer :
+			        GameDrawingArea.SolutionType.InvalidAnswer);
 
-			session.CurrentGame.DrawAnswer = true;
+			session.CurrentGame.Answer.Draw = true;
 			ActiveInputControls (true);
 			next_button.GrabFocus ();
 			drawing_area.QueueDraw ();
@@ -536,19 +477,59 @@ namespace gbrainy.Clients.Classical
 			if (session.CurrentGame == null)
 				return;
 
-			UpdateSolution (session.CurrentGame.TipString);
+			UpdateSolution (session.CurrentGame.TipString, GameDrawingArea.SolutionType.Tip);
 		}
 
 		void OnNewGame (GameSession.Types type)
 		{
+			// If the translation is lower than MIN_TRANSLATION explain that running the English version is an option
+			if (ShowTranslationWarning ())
+				Translations ();
+
 			session.Type = type;
 			session.New ();
 			GetNextGame ();
 			GameSensitiveUI ();
-			UpdateSolution (Catalog.GetString ("Once you have an answer type it in the \"Answer:\" entry box and press the \"OK\" button."));
+			UpdateSolution (Catalog.GetString ("Once you have an answer type it in the \"Answer:\" entry box and press the \"OK\" button."),
+				GameDrawingArea.SolutionType.Tip);
 			UpdateStatusBar ();
 		}
 
+		public bool ShowTranslationWarning ()
+		{
+			// Notify the user once per version only
+			if (String.Compare (Preferences.Get <string> (Preferences.EnglishVersionKey), Defines.VERSION, 0) == 0)
+				return false;
+
+			int percentage = ServiceLocator.Instance.GetService <ITranslations> ().TranslationPercentage;
+			if (percentage > 0 && percentage < MIN_TRANSLATION)
+			{
+				Preferences.Set <string> (Preferences.EnglishVersionKey, Defines.VERSION);
+				Preferences.Save ();
+				return true;
+			}
+
+			return false;
+		}
+
+		void Translations ()
+		{		
+			HigMessageDialog dlg;
+	
+			dlg = new HigMessageDialog (app_window,
+				Gtk.DialogFlags.DestroyWithParent,
+				Gtk.MessageType.Warning,
+				Gtk.ButtonsType.Ok,
+				Catalog.GetString ("The level of translation of gbrainy for your language is low."),
+				Catalog.GetString ("You may be exposed to partially translated games making it more difficult to play. If you prefer to play in English, there is an option for doing so in gbrainy's Preferences."));
+		
+			try {
+	 			dlg.Run ();
+	 		} finally {
+	 			dlg.Destroy ();
+	 		}
+		}
+
 		void OnMathOnly (object sender, EventArgs args)
 		{
 			OnNewGame (GameSession.Types.Calculation);
@@ -567,10 +548,10 @@ namespace gbrainy.Clients.Classical
 		void OnPdfExport (object sender, EventArgs args)
 		{
 			PdfExportDialog pdf;
-			
+
 			pdf = new PdfExportDialog ();
 			pdf.Run ();
-			pdf.Destroy (); 
+			pdf.Destroy ();
 		}
 
 		void OnPreferences (object sender, EventArgs args)
@@ -579,7 +560,11 @@ namespace gbrainy.Clients.Classical
 
 			dialog = new PreferencesDialog (session.PlayerHistory);
 			if ((Gtk.ResponseType) dialog.Run () == ResponseType.Ok) {
-				session.Difficulty = (GameDifficulty) Preferences.GetIntValue (Preferences.DifficultyKey);
+				session.Difficulty = (GameDifficulty) Preferences.Get <int> (Preferences.DifficultyKey);
+				session.GameManager.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
+
+				if (dialog.NewThemeSet == true)
+					drawing_area.ReloadBackground ();
 			}
 			dialog.Destroy ();
 		}
@@ -618,7 +603,7 @@ namespace gbrainy.Clients.Classical
 		{
 			session.End ();
 
-			UpdateSolution (String.Empty);
+			UpdateSolution (String.Empty, GameDrawingArea.SolutionType.None);
 			UpdateQuestion (String.Empty);
 			UpdateStatusBar ();
 			GameSensitiveUI ();
@@ -630,18 +615,19 @@ namespace gbrainy.Clients.Classical
 		void SetPauseResumeButtonUI (bool pause)
 		{
 			if (pause) {
-				pause_tbbutton.StockId = "pause";
-				pause_tbbutton.Label = Catalog.GetString ("Pause");
+				drawing_area.Paused = false;
+				toolbar.PauseButton.StockId = "pause";
+				toolbar.PauseButton.Label = Catalog.GetString ("Pause");
 				ActiveInputControls (true);
 			} else {
-				pause_tbbutton.StockId = "resume";
-				pause_tbbutton.Label = Catalog.GetString ("Resume");
+				drawing_area.Paused = true;
+				toolbar.PauseButton.StockId = "resume";
+				toolbar.PauseButton.Label = Catalog.GetString ("Resume");
 				ActiveInputControls (false);
 			}
 			UpdateStatusBar ();
 		}
 
-
 		void SetPauseResumeButton (bool pause)
 		{
 			if (pause)
@@ -657,23 +643,58 @@ namespace gbrainy.Clients.Classical
 			SetPauseResumeButton (session.Paused);
 		}
 
-		private void OnToolbarActivate (object sender, System.EventArgs args)
+		void OnActivateToolbar (object sender, System.EventArgs args)
 		{
 			int width, height;
 			Requisition requisition;
 
-			requisition =  toolbar.SizeRequest ();
+			requisition = toolbar.SizeRequest ();
 			app_window.GetSize (out width, out height);
 			toolbar.Visible = !toolbar.Visible;
 
 			if (toolbar.Visible)
 				toolbar.ShowArrow = false;
 
-			Preferences.SetBoolValue (Preferences.ToolbarKey, toolbar.Visible);
-			Preferences.Save ();
+			toolbar_orientation_menuitem.Sensitive = toolbar.Visible;
+
+			if (Preferences.Get <bool> (Preferences.ToolbarShowKey) != toolbar.Visible)
+			{
+				Preferences.Set <bool> (Preferences.ToolbarShowKey, toolbar.Visible);
+				Preferences.Save ();
+			}
 			app_window.Resize (width, height - requisition.Height);
 		}
 
+		void OnVerticalToolbar (object sender, System.EventArgs args)
+		{
+			if (toolbar.InitCompleted  == false)
+				return;
+
+			const Gtk.Orientation orientation = Gtk.Orientation.Vertical;
+
+			if ((Gtk.Orientation) Preferences.Get <int> (Preferences.ToolbarOrientationKey) != orientation)
+			{
+				Preferences.Set <int> (Preferences.ToolbarOrientationKey, (int) orientation);
+				Preferences.Save ();
+			}
+			toolbar.Attach (orientation);
+		}
+
+		void OnHorizontalToolbar (object sender, System.EventArgs args)
+		{
+			if (toolbar.InitCompleted  == false)
+				return;
+
+			const Gtk.Orientation orientation = Gtk.Orientation.Horizontal;
+
+			if ((Gtk.Orientation) Preferences.Get <int> (Preferences.ToolbarOrientationKey) != orientation)
+			{
+				Preferences.Set <int>  (Preferences.ToolbarOrientationKey, (int) Gtk.Orientation.Horizontal);
+				Preferences.Save ();
+			}
+			toolbar.Attach (orientation);
+		}
+
 		void OnHistory (object sender, EventArgs args)
 		{
 			PlayerHistoryDialog dialog;
@@ -683,29 +704,12 @@ namespace gbrainy.Clients.Classical
 			dialog.Destroy ();
 		}
 
-		private void AddIcon (IconFactory stock, string stockid, string resource)
-		{
-			Gtk.IconSet iconset = stock.Lookup (stockid);
-
-			if (iconset != null)
-				return;
-
-			iconset = new Gtk.IconSet ();
-			Gdk.Pixbuf img = Gdk.Pixbuf.LoadFromResource (resource);
-			IconSource source = new IconSource ();
-			source.Pixbuf = img;
-			iconset.AddSource (source);
-			stock.Add (stockid, iconset);
-		}
-
 		void OnFullscreen (object sender, EventArgs args)
 		{
 			if (full_screen == false) {
-				margins = true;
 				app_window.Fullscreen ();
 			}
 			else {
-				margins = false;
 				app_window.Unfullscreen ();
 			}
 
@@ -717,11 +721,25 @@ namespace gbrainy.Clients.Classical
 			Process.Start ("http://live.gnome.org/gbrainy/Extending");
 		}
 
+		static void InitCoreLibraries ()
+		{
+			new DefaultServices ().RegisterServices ();
+
+			// Configuration
+			ServiceLocator.Instance.GetService <IConfiguration> ().Set (ConfigurationKeys.GamesDefinitions, Defines.DATA_DIR);
+			ServiceLocator.Instance.GetService <IConfiguration> ().Set (ConfigurationKeys.GamesGraphics, Defines.DATA_DIR);
+			ServiceLocator.Instance.GetService <IConfiguration> ().Set (ConfigurationKeys.ThemesDir, Defines.DATA_DIR);
+
+			string assemblies_dir;
+			assemblies_dir =  System.IO.Path.GetDirectoryName (Assembly.GetExecutingAssembly ().Location);
+			ServiceLocator.Instance.GetService <IConfiguration> ().Set (ConfigurationKeys.AssembliesDir, assemblies_dir);
+		}
+
 		public static void Main (string [] args)
 		{
 			try {
 				Unix.SetProcessName ("gbrainy");
-			} 
+			}
 			catch (Exception e)
 			{
 				Console.WriteLine ("gbrainy.Main. Could not set process name. Error {0}", e);
@@ -729,6 +747,8 @@ namespace gbrainy.Clients.Classical
 
 			DateTime start_time = DateTime.Now;
 
+			InitCoreLibraries ();
+
 			GtkClient app = new GtkClient ();
 			CommandLine.Version ();
 
@@ -742,16 +762,17 @@ namespace gbrainy.Clients.Classical
 #endif
 
 			app.Initialize ();
+			// Set RandomOrder before setting the custom list then it has effect of custom games
+			app.Session.GameManager.RandomOrder = line.RandomOrder;
 			if (line.PlayList.Length > 0) {
 				app.Session.GameManager.PlayList = line.PlayList;
 				app.InitialSessionType = GameSession.Types.Custom;
 			}
-			app.Session.GameManager.RandomOrder = line.RandomOrder;
 			app.ProcessDefaults ();
+			ThemeManager.Load ();
 
 			TimeSpan span = DateTime.Now - start_time;
 			Console.WriteLine (Catalog.GetString ("Startup time {0}"), span);
-
 #if GNOME
 			app.Run ();
 #else
