@@ -32,10 +32,10 @@ namespace gbrainy.Core.Libraries
 	public class CairoContext : Cairo.Context
 	{
 		Pango.Layout layout;
+		FontDescription font_description;
 		double font_size;
-
+		const double def_linespace = 0.018;
 		const double width_margin = 0.04;
-		const double line_spacing = 0.018;
 
 		public CairoContext (IntPtr state, Gtk.Widget widget) : base (state)
 		{
@@ -43,34 +43,55 @@ namespace gbrainy.Core.Libraries
 
 			// We do not honor DPI settings or font sizes (just font name)
 			// User should resize the window
-			layout.FontDescription = widget.PangoContext.FontDescription.Copy ();
+			font_description = layout.FontDescription = widget.PangoContext.FontDescription.Copy ();
+			FontLineSpace = def_linespace;
 		}
 
 		// Used by GeneratePDF
 		public CairoContext (Cairo.Surface s, string font, int dpis) : base (s)
 		{
 			layout = Pango.CairoHelper.CreateLayout (this);
-			layout.FontDescription = FontDescription.FromString (font);
+			font_description = layout.FontDescription = FontDescription.FromString (font);
 
 			if (dpis > 0)  {
 				Pango.Context c = layout.Context;
 				Pango.CairoHelper.ContextSetResolution (c, dpis);
 				c.Dispose ();
 			}
+			FontLineSpace = def_linespace;
 		}
 
-		// True if we want Pango to process XML entites and formatting attributes
+		new public string FontFace {
+			set {
+				if (String.IsNullOrEmpty (value) == true)
+					return;
+
+				if (font_description != null)
+					font_description.Dispose ();
+
+				font_description = layout.FontDescription = Pango.FontDescription.FromString (value);
+			}
+		}
+
+		public double FontLineSpace { get; set; }
+
+		// True if we want Pango to process XML entities and formatting attributes
 		public bool UseMarkup  { get; set; }
 
 		// No dispose of resources on this class
 		protected override void Dispose (bool disposing)
 		{
 			layout.Dispose ();
+
+			if (font_description != null)
+				font_description.Dispose ();
 		}
 
 		private void UpdateFontSize ()
 		{
-			layout.FontDescription.Size = (int) (font_size * Pango.Scale.PangoScale * Matrix.Xx);
+			// For questions and answers area the size is not necessary proportional
+			double m = Matrix.Yy < Matrix.Xx ? Matrix.Yy : Matrix.Xx;
+			layout.FontDescription.Size = (int) (font_size * Pango.Scale.PangoScale * m);
 		}
 
 		/*
@@ -189,7 +210,7 @@ namespace gbrainy.Core.Libraries
 			int w, h, spacing;
 			Cairo.Matrix old = Matrix;
 
-			if (max_width < 0 )
+			if (max_width < 0)
 				throw new ArgumentOutOfRangeException ("Invalid maximum width value");
 
 			MoveTo (x, y);
@@ -198,7 +219,7 @@ namespace gbrainy.Core.Libraries
 
 			spacing = layout.Spacing;
 			layout.Width = (int) (max_width * old.Xx * Pango.Scale.PangoScale);
-			layout.Spacing = (int) (line_spacing * (old.Yy * Pango.Scale.PangoScale));
+			layout.Spacing = (int) (FontLineSpace * (old.Yy * Pango.Scale.PangoScale));
 
 			layout.SingleParagraphMode = false;
 			SetText (str);
@@ -222,7 +243,7 @@ namespace gbrainy.Core.Libraries
 
 			spacing = layout.Spacing;
 			layout.Width = (int) (max_width * old.Xx * Pango.Scale.PangoScale);
-			layout.Spacing = (int) (line_spacing * (old.Xx * Pango.Scale.PangoScale));
+			layout.Spacing = (int) (FontLineSpace * (old.Xx * Pango.Scale.PangoScale));
 
 			layout.SingleParagraphMode = !wrapping;
 			SetText (str);
@@ -274,7 +295,7 @@ namespace gbrainy.Core.Libraries
 			}
 		}
 
-		void DrawImage (SVGImage image, double x, double y, double width, double height)
+		public void DrawImage (SVGImage image, double x, double y, double width, double height)
 		{
 			Save ();
 			Translate (x, y);
