@@ -19,9 +19,9 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Calculation
 {
@@ -32,11 +32,11 @@ namespace gbrainy.Games.Calculation
 		private char oper1, oper2;
 
 		public override string Name {
-			get {return Catalog.GetString ("Operators");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Operators");}
 		}
 
 		public override string Tip {
-			get {return String.Format( Catalog.GetString ("The first operator is {0}."), oper1);}
+			get {return String.Format( ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The first operator is {0}."), oper1);}
 		}
 
 		public override GameTypes Type {
@@ -44,22 +44,10 @@ namespace gbrainy.Games.Calculation
 		}
 
 		public override string Question {
-			get {return String.Format (Catalog.GetString ("Which operators make {0}, {1}, and {2} equal {3}? Answer using '+-/*'."), number_a, number_b, number_c, total);}
+			get {return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Which operators make {0}, {1}, and {2} equal {3}? Answer using '+-/*'."), number_a, number_b, number_c, total);}
 		}
 
-		public override string AnswerCheckExpression {
-			get { return "[+*-/]"; }
-		}
-
-		public override GameAnswerCheckAttributes CheckAttributes {
-			get { return GameAnswerCheckAttributes.Trim | GameAnswerCheckAttributes.MatchAll; }
-		}
-
-		public override string AnswerValue {
-			get { return String.Format (Catalog.GetString ("{0} and {1}"), oper1, oper2); }
-		}
-
-		private double ProcessOperation (double total, double number, char op)
+		static private double ProcessOperation (double total, double number, char op)
 		{
 			switch (op) {
 			case '-':
@@ -116,7 +104,10 @@ namespace gbrainy.Games.Calculation
 					break;
 			}
 
-			right_answer = String.Format ("{0} | {1}", oper1, oper2);
+			Answer.Correct = String.Format ("{0} | {1}", oper1, oper2);
+			Answer.CheckExpression = "[+*-/]";
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MatchAll;
+			Answer.CorrectShow = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0} and {1}"), oper1, oper2);
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
@@ -137,10 +128,10 @@ namespace gbrainy.Games.Calculation
 			gr.DrawTextAlignedRight (aligned_pos, DrawAreaY + 0.55, total.ToString ());
 
 			gr.MoveTo (DrawAreaX + 0.2, DrawAreaY + 0.25);
-			gr.ShowPangoText ((DrawAnswer == true) ? oper1.ToString () : "?");
+			gr.ShowPangoText ((Answer.Draw == true) ? oper1.ToString () : "?");
 
 			gr.MoveTo (DrawAreaX + 0.2, DrawAreaY + 0.35);
-			gr.ShowPangoText ((DrawAnswer == true) ?  oper2.ToString () : "?");
+			gr.ShowPangoText ((Answer.Draw == true) ?  oper2.ToString () : "?");
 
 		}
 	}
