@@ -17,11 +17,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -35,24 +35,27 @@ namespace gbrainy.Games.Logic
 		private const int handle_num = 2;
 
 		public override string Name {
-			get {return Catalog.GetString ("Clocks");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Clocks");}
 		}
 
 		public override string Question {
 			get {return (String.Format (
 				// Translators: {0} is replaced by 'Figure X'
-				Catalog.GetString ("To what number should the large handle of the '{0}' clock point? Answer using numbers."),
-				GetPossibleFigureAnswer (3)));}
+				ServiceLocator.Instance.GetService <ITranslations> ().GetString ("To what number should the large handle of the '{0}' clock point? Answer using numbers."),
+				Answer.GetFigureName (3)));}
 		}
 
 		public override string Rationale {
 			get {
-				return String.Format (Catalog.GetString ("Starting from the first clock sum {0} to the value indicated by the hands."), addition);
+				// Translators: {0} is replaced by 'Figure X'
+				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString (
+					"Starting from the first clock, add {1} to the number obtained by appending the values to which the hands point, for '{0}' is {2} + {1} = {3}."), 
+					Answer.GetFigureName (3), addition, handles [4].ToString () + handles [5].ToString (), handles [6].ToString () + handles [7].ToString ());
 			}
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("The clocks do not follow the time logic.");}
+			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The clocks do not follow the time logic.");}
 		}
 
 		protected override void Initialize ()
@@ -84,8 +87,8 @@ namespace gbrainy.Games.Logic
 				handles [i + 1] = position - ((position / 10) * 10);
 				position += addition;
 			}
-		
-			right_answer = handles[7].ToString ();
+
+			Answer.Correct = handles[7].ToString ();
 
 			// First row
 			HorizontalContainer container = new HorizontalContainer (DrawAreaX, 0.05, 0.8, 0.45);
@@ -99,7 +102,7 @@ namespace gbrainy.Games.Logic
 			drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 			{
 				DrawClock (e.Context, 0.2, 0.16, handles[0], handles[1], true);
-				e.Context.DrawTextCentered (drawable_area.Width / 2, 0.36, GetPossibleFigureAnswer (0));
+				e.Context.DrawTextCentered (drawable_area.Width / 2, 0.36, Answer.GetFigureName (0));
 				e.Context.Stroke ();
 			};
 
@@ -111,7 +114,7 @@ namespace gbrainy.Games.Logic
 			{
 				DrawClock (e.Context, 0.2, 0.16, handles[2], handles[3], true);
 				e.Context.MoveTo (0.03, 0.29);
-				e.Context.DrawTextCentered (drawable_area.Width / 2, 0.36, GetPossibleFigureAnswer (1));
+				e.Context.DrawTextCentered (drawable_area.Width / 2, 0.36, Answer.GetFigureName (1));
 				e.Context.Stroke ();
 			};
 
@@ -126,7 +129,7 @@ namespace gbrainy.Games.Logic
 			drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 			{
 				DrawClock (e.Context, 0.2, 0.16, handles[4], handles[5], true);
-				e.Context.DrawTextCentered (drawable_area.Width / 2, 0.36, GetPossibleFigureAnswer (2));
+				e.Context.DrawTextCentered (drawable_area.Width / 2, 0.36, Answer.GetFigureName (2));
 				e.Context.Stroke ();
 			};
 
@@ -136,9 +139,9 @@ namespace gbrainy.Games.Logic
 
 			drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 			{
-				DrawClock (e.Context, 0.2, 0.16, handles[6], handles[7], DrawAnswer == true);
+				DrawClock (e.Context, 0.2, 0.16, handles[6], handles[7], Answer.Draw == true);
 				e.Context.MoveTo (0.03, 0.29);
-				e.Context.DrawTextCentered (drawable_area.Width / 2, 0.36, GetPossibleFigureAnswer (3));
+				e.Context.DrawTextCentered (drawable_area.Width / 2, 0.36, Answer.GetFigureName (3));
 				e.Context.Stroke ();
 			};
 	
@@ -202,10 +205,5 @@ namespace gbrainy.Games.Logic
 			gr.LineTo (x + x0 * 0.4, y + y0 * 0.4);
 			gr.Stroke ();
 		}
-
-		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
-		{
-			base.Draw (gr, area_width, area_height, rtl);
-		}
 	}
 }
